#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2021-08-10
#
# 2023-04-23: moved wato file to ~/local/lib/check_mk/gui/plugins/wato
#             moved rule set from networking to hardware

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    TextAscii,
    MonitoringState,
)
from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    rulespec_registry,
    RulespecGroupCheckParametersHardware,
)


def _parameter_valuespec_checkpoint_powersupply():
    return Dictionary(elements=[
        ('ps_not_up',
         MonitoringState(
             default_value=2,
             title=_('State if power supply is not "UP" or "Present".'),
         )),
    ])


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name='checkpoint_powersupply',
        group=RulespecGroupCheckParametersHardware,
        item_spec=lambda: TextAscii(title=_('Power Supply index'), ),
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_checkpoint_powersupply,
        title=lambda: _('Check Point Power Supply'),
    ))
